@@ -166,6 +166,13 @@ sub DEFAULT_PROFILES {{
       anchor => '-25',
     },
   },
+  markdown => {
+    width => 250,
+    renderer 	=> 'Ext.ux.RapidApp.renderSourceCodeLineNumbers', # this cannot be "chained" with []
+    editor => {
+      xtype		=> 'ra-md-editor',
+    },
+  },
   email => {
     width => 100,
     editor => { xtype => 'textfield', vtype => 'email' },
@@ -278,7 +285,12 @@ sub DEFAULT_PROFILES {{
     auto_editor_params => { user_editable => 1 }
   },
   hidden => {
-    no_column => \1, no_quick_search => \1, no_multifilter => \1
+    no_column => \1, 
+    allow_add => \0, 
+    allow_edit => \0,
+    allow_batchedit => \0,
+    no_quick_search => \1, 
+    no_multifilter => \1
   },
   multirel => {
     multifilter_type => 'number',
